summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-14 23:26:59 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-14 23:39:48 -0500
commit7d76ba739364941aa87f57c01e2bc3e1ee301980 (patch)
tree779447468cc31507942e6c3841e529eca3269b81 /png.h
parent8f23c9264274a1638b7ef385175f881ded4b885d (diff)
downloadlibpng-7d76ba739364941aa87f57c01e2bc3e1ee301980.tar.gz
[libpng14] Imported from libpng-1.4.10.tarv1.4.10
Diffstat (limited to 'png.h')
-rw-r--r--png.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/png.h b/png.h
index f4c023d25..1347a5074 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.10rc02 - March 6, 2012
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.10rc02 - March 6, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -166,6 +166,7 @@
* 1.4.9 14 10409 14.so.14.9[.0]
* 1.4.10beta01 14 10410 14.so.14.10[.0]
* 1.4.10rc01-02 14 10410 14.so.14.10[.0]
+ * 1.4.10 14 10410 14.so.14.10[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -197,7 +198,7 @@
*
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.10rc02, March 6, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.10, March 15, 2012, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -309,13 +310,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 6, 2012
+ * March 15, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.10rc02 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.10 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -371,9 +372,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.10rc02"
+#define PNG_LIBPNG_VER_STRING "1.4.10"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.10rc02 - March 6, 2012\n"
+ " libpng version 1.4.10 - March 15, 2012\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -386,7 +387,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 0
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -403,7 +404,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -1497,7 +1498,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_10rc02;
+typedef png_structp version_1_4_10;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.10rc02 - March 6, 2012
+ * libpng version 1.4.10 - March 15, 2012
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.10rc02 - March 6, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.10 - March 15, 2012: Glenn
* See also "Contributing Authors", below.
*